summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Makefile60
-rw-r--r--Makefile.config23
-rw-r--r--docs/README46
-rwxr-xr-xkernel/check_mar.pl2
-rwxr-xr-xkernel/update_kernel2
-rw-r--r--mdk-stage1/config-stage1.h4
-rw-r--r--mdk-stage1/disk.c4
-rw-r--r--mdk-stage1/doc/TECH-INFOS2
-rw-r--r--mdk-stage1/network.c2
-rw-r--r--perl-install/Makefile9
-rw-r--r--perl-install/Makefile.config15
-rw-r--r--perl-install/Makefile.drakxtools1
-rw-r--r--perl-install/install2.pm8
-rw-r--r--perl-install/install_any.pm22
-rw-r--r--perl-install/install_steps.pm4
-rw-r--r--perl-install/install_steps_gtk.pm2
-rw-r--r--perl-install/lang.pm2
-rw-r--r--perl-install/modules.pm2
-rw-r--r--perl-install/pkgs.pm16
-rw-r--r--perl-install/share/advertising/Makefile13
-rw-r--r--perl-install/share/po/Makefile1
-rwxr-xr-xperl-install/standalone/drakpxe6
-rw-r--r--rescue/Makefile8
-rw-r--r--tools/Makefile23
-rw-r--r--tools/i386/netboot/menu.lst.example6
-rwxr-xr-xtools/make_mdkinst_stage26
26 files changed, 148 insertions, 141 deletions
diff --git a/Makefile b/Makefile
index 409a03191..5acf54a43 100644
--- a/Makefile
+++ b/Makefile
@@ -1,11 +1,7 @@
-ROOTDEST = /export
+include Makefile.config
DIRS = tools kernel mdk-stage1 perl-install rescue
-
-ARCH := $(patsubst i%86,i386,$(shell uname -m))
-ARCH := $(patsubst sparc%,sparc,$(ARCH))
-
.PHONY: dirs install
install: dirs images rescue install_only
@@ -22,29 +18,29 @@ tar: clean
rm needed_rpms.lst
install_only:
- for i in images misc Mandrake Mandrake/base Mandrake/share; do install -d $(ROOTDEST)/$$i ; done
+ install -d $(MISC_DEST) $(EXTRA_INSTALL_DEST) $(IMAGES_DEST) $(MEDIA_INFO_DEST)
ifneq (ppc,$(ARCH))
- cp -f images/* $(ROOTDEST)/images
+ cp -f images/* $(IMAGES_DEST)
endif
ifeq (alpha,$(ARCH))
cp -f images/* $(ROOTDEST)/boot
cp -f vmlinux.gz $(ROOTDEST)/boot/instboot.gz
make -C tools/$(ARCH)/cd install ROOTDEST=$(ROOTDEST)
endif
- cd $(ROOTDEST)/images; rm -rf alternatives
- if [ `ls $(ROOTDEST)/images/*.img-* 2>/dev/null | wc -l` -gt 0 ]; then \
- cd $(ROOTDEST)/images; mkdir alternatives; cd alternatives; mv ../*.img-* .; md5sum *.img-* > MD5SUM; \
+ rm -rf $(IMAGES_DEST)/alternatives
+ if [ `ls $(IMAGES_DEST)/*.img-* 2>/dev/null | wc -l` -gt 0 ]; then \
+ cd $(IMAGES_DEST); mkdir alternatives; cd alternatives; mv ../*.img-* .; md5sum *.img-* > MD5SUM; \
fi
- cd $(ROOTDEST)/images; md5sum *.{img,iso}* > MD5SUM
+ cd $(IMAGES_DEST); md5sum *.{img,iso}* > MD5SUM
ifeq (i386,$(ARCH))
- rm -rf $(ROOTDEST)/isolinux
- cp -af isolinux $(ROOTDEST)
+ rm -rf $(GENERIC_INSTALL_DEST)/isolinux
+ cp -af isolinux $(GENERIC_INSTALL_DEST)
endif
ifeq (x86_64,$(ARCH))
- rm -rf $(ROOTDEST)/isolinux
- cp -af isolinux $(ROOTDEST)
+ rm -rf $(GENERIC_INSTALL_DEST)/isolinux
+ cp -af isolinux $(GENERIC_INSTALL_DEST)
endif
make -C perl-install full_stage2
@@ -57,7 +53,7 @@ clean:
find . -name "*~" -o -name ".#*" | xargs rm -f
check:
- @badrights=`find $(ROOTDEST)/Mandrake/mdkinst | perl -lne 'print if !((stat)[2] & 4)'`; [ -z "$$badrights" ] || { echo "bad rights for files vvvvvvvvvvvvvvvvvvvvvvvvvv" ; echo "$$badrights" ; echo "bad rights for files ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^" ; exit 1; }
+ @badrights=`find $(STAGE2_LIVE) | perl -lne 'print if !((stat)[2] & 4)'`; [ -z "$$badrights" ] || { echo "bad rights for files vvvvvvvvvvvvvvvvvvvvvvvvvv" ; echo "$$badrights" ; echo "bad rights for files ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^" ; exit 1; }
@missing_kb=`find -name "Entries" | xargs perl -F/ -alne 'print $$ARGV =~ m|(.*)/CVS|, "/$$F[1]" if $$F[1] =~ /\.(png|gif|bmp|xcf|gz|bz2|tar|rdz|so|a|o|mar|img|exe)$$/ && $$F[4] ne "-kb"'` ; [ -z "$$missing_kb" ] || { echo "missing -kb in CVS for files vvvvvvvvvvvvvvvvvvvvvvvvvv" ; echo "$$missing_kb" ; echo "missing -kb in CVS for files ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^" ; exit 1; }
upload:
@@ -71,20 +67,20 @@ upload:
$(MAKE) upload_only
upload_only:
- function upload() { rsync -qSavz --verbose --exclude '*~' -e ssh --delete $(ROOTDEST)/$$1/$$2 mandrake@ken:/c/cooker/$$1; } ;\
- upload Mandrake/mdkinst '' ;\
- upload Mandrake/base 'compssUsers*' ;\
- upload Mandrake/base rpmsrate ;\
- upload Mandrake/base '*_stage2.bz2' ;\
- upload Mandrake/share/advertising '' ;\
- upload misc gendistrib ;\
- upload misc make_mdkinst_stage2 ;\
- upload misc packdrake ;\
- upload misc packdrake.pm ;\
- upload misc auto ;\
- upload images MD5SUM ;\
- upload images '*.img*' ;\
- upload images '*.iso*' ;\
- upload images/alternatives '' ;\
- upload isolinux '' ;\
+ function upload() { rsync -qSavz --verbose --exclude '*~' -e ssh --delete $$1/$$2 mandrake@ken:/c/cooker/$$1; } ;\
+ upload $(STAGE2_LIVE) '' ;\
+ upload $(MEDIA_INFO_DEST) 'compssUsers*' ;\
+ upload $(MEDIA_INFO_DEST) rpmsrate ;\
+ upload $(GENERIC_INSTALL_DEST) '*_stage2.bz2' ;\
+ upload $(EXTRA_INSTALL_DEST)/advertising '' ;\
+ upload $(MISC_DEST) gendistrib ;\
+ upload $(MISC_DEST) make_mdkinst_stage2 ;\
+ upload $(MISC_DEST) packdrake ;\
+ upload $(MISC_DEST) packdrake.pm ;\
+ upload $(MISC_DEST) auto ;\
+ upload $(IMAGES_DEST) MD5SUM ;\
+ upload $(IMAGES_DEST) '*.img*' ;\
+ upload $(IMAGES_DEST) '*.iso*' ;\
+ upload $(IMAGES_DEST)/alternatives '' ;\
+ upload $(GENERIC_INSTALL_DEST)/isolinux '' ;\
echo
diff --git a/Makefile.config b/Makefile.config
new file mode 100644
index 000000000..793fd669e
--- /dev/null
+++ b/Makefile.config
@@ -0,0 +1,23 @@
+ROOTDEST = /export
+MISC_DEST = $(ROOTDEST)/misc
+GENERIC_INSTALL_DEST = $(ROOTDEST)/install
+EXTRA_INSTALL_DEST = $(GENERIC_INSTALL_DEST)/extra
+IMAGES_DEST = $(GENERIC_INSTALL_DEST)/images
+STAGE2_DEST = $(GENERIC_INSTALL_DEST)/stage2
+STAGE2_LIVE = $(STAGE2_DEST)/live
+
+MAIN_RPMS_DIR = $(ROOTDEST)/media/main
+MEDIA_INFO_DEST = $(ROOTDEST)/media/media_info
+
+
+
+
+# not config, but useful everywhere :)
+ARCH := $(patsubst i%86,i386,$(shell uname -m))
+ARCH := $(patsubst sparc%,sparc,$(ARCH))
+
+ifeq (x86_64, $(ARCH))
+LIB = lib64
+else
+LIB = lib
+endif
diff --git a/docs/README b/docs/README
index 4a023ae95..d14120c5d 100644
--- a/docs/README
+++ b/docs/README
@@ -42,16 +42,16 @@ one is the main one :
(2) multi-cdrom install
DIRS == the root directories of all the media that the install will see
-``gendistrib'' will scan the file Mandrake/base/hdlists in the main root
+``gendistrib'' will scan the file media/media_info/hdlists in the main root
directory (the first one in DIRS) to search for all media used. Typically you
-use Mandrake/RPMS* for RPM packages repository.
-For multi-cd, please use Mandrake/RPMS or Mandrake/RPMS1, Mandrake/RPMS2, etc.
-For one CD or a network/hd volume, please use Mandrake/RPMS.
+use media/main for RPM packages repository.
+For multi-cd, please use media/main or media/foo, etc.
+For one CD or a network/hd volume, please use media/main.
-Optionnally, you can modify ``Mandrake/base/rpmsrate''; this file manages
+Optionnally, you can modify ``media/media_info/rpmsrate''; this file manages
the relative importance of the files, and thus their installation or not.
-Also, mdkinst_stage2.gz must be remade if you modify files in Mandrake/mdkinst.
+Also, mdkinst_stage2.gz must be remade if you modify files in install/stage2/live.
See below for information about these files.
********************************************************************************
@@ -59,7 +59,7 @@ See below for information about these files.
********************************************************************************
First here are the different things needed :
-Mandrake/base/hdlists
+media/media_info/hdlists
description of the available install media.
format is one line for one medium as
<hdlist_name> <rpms_directory> <description>
@@ -68,26 +68,26 @@ Mandrake/base/hdlists
hdlist1.cz Mandrake/RPMS1 Boot CD
hdlist2.cz Mandrake/RPMS2 Extension CD
-Mandrake/base/hdlist*.cz
+media/media_info/hdlist*.cz
table of rpm's headers, referred by ``hdlists''
their contents can be listed using ``packdrake -l <hdlist_file>'' or
or ``parsehdlist <hdlist_file>''.
- ! Need to be remade when Mandrake/RPMS* changes (with ``gendistrib'') !
+ ! Need to be remade when media/main changes (with ``gendistrib'') !
-Mandrake/base/depslist.ordered
+media/media_info/depslist.ordered
for each packages, tell which package it depends on. Also contains the
size for some (obscure) bloody reasons.
- ! Need to be remade when Mandrake/RPMS* changes !
+ ! Need to be remade when media/main changes !
(with ``gendistrib --noclean --distrib .'')
-Mandrake/base/compssUsers
+media/media_info/compssUsers
-Mandrake/base/rpmsrate
+media/media_info/rpmsrate
ranks and classify packages, so that the installer will know which
ones to install. format is :
<intern_group>
<level> <packages>
- where <intern_group> is a symbolic name used in Mandrake/base/compssUsers* files,
+ where <intern_group> is a symbolic name used in media/media_info/compssUsers* files,
and <level> defines importance level as described below :
5 must have
4 important
@@ -98,28 +98,28 @@ Mandrake/base/rpmsrate
and 5 (must have). export mode add 3 (very nice) level. other level (below 2)
can only be selected using individual package selection.
-Mandrake/mdkinst
+install/stage2/live
live system used on certain installs. See ``Ramdisk or not'' below for
more.
-Mandrake/base/mdkinst_stage2.bz2
+install/stage2/mdkinst_stage2.bz2
for the ramdisk. live sytem in ext2 filesystem bzipped2.
- generated from Mandrake/mdkinst tree using misc/make_mdkinst_stage2
+ generated from install/stage2/live tree using misc/make_mdkinst_stage2
See ``Ramdisk or not'' below for more.
-Mandrake/base/rescue_stage2.bz2
+install/stage2/rescue_stage2.bz2
rescue ramdisk. live sytem in ext2 filesystem bzipped2.
this is the ramdisk loaded when typing rescue on boot prompt.
there is no live system available, only the ramdisk is used.
-images/*.img
+install/images/*.img
floppy boot images to use with DrakX. Use:
- cdrom.img for cdrom install
- network.img + network_drivers.img for ftp/nfs install (non-pcmcia devices)
- hd_grub.img for hard-disk install (see http://qa.mandrakesoft.com/hd_grub.cgi)
- pcmcia.img for pcmcia install (see ``PCMCIA install'' below for more)
-images/boot.iso
+install/images/boot.iso
iso image to burn enabling any install (cdrom/hd/nfs/ftp)
********************************************************************************
@@ -183,7 +183,7 @@ used is getting big, and costs a lot in memory
| nfs | live | live
| ftp | ramdisk | ramdisk
| http | ramdisk | ramdisk
-| hd | ramdisk | live if Mandrake/mdkinst/usr/bin/runinstall2 is a link,
+| hd | ramdisk | live if install/stage2/live/usr/bin/runinstall2 is a link,
| | | ramdisk otherwise
| cdrom | ramdisk | live if memory < 52MB, ramdisk otherwise
@@ -193,7 +193,7 @@ a failure dialog will be printed explaining that there is not enough memory
to perform the installation.
When i say live, it means that the stage1 will *mount* the
-Mandrake/mdkinst and use it that way.
+install/stage2/live and use it that way.
The ramdisk is used in place of the live in some cases. This ramdisk is filled
with mdkinst_stage2.gz
@@ -267,7 +267,7 @@ providing this file:
- from a floppy disk; use "kickstart=floppy" as kernel parameter,
as explained in the document
- from the installation volume itself; put the file in the
- "Mandrake/base" directory of the installation volume; use
+ "install" directory of the installation volume; use
"kickstart" only, or "kickstart=filename" to specify another
filename than auto_inst.cfg
- specified by the network; setup your DHCP server to provide the
diff --git a/kernel/check_mar.pl b/kernel/check_mar.pl
index 7b9fefbbf..f9f8ae217 100755
--- a/kernel/check_mar.pl
+++ b/kernel/check_mar.pl
@@ -8,7 +8,7 @@ my $mar = '../mdk-stage1/mar/mar';
my %sanity_check = (
cdrom => [
qw(aic7xxx),
- if_(arch() !~ /ppc|x86_64/, 'advansys'),
+# if_(arch() !~ /ppc|x86_64/, 'advansys'),
],
all => [
qw(3c59x eepro100 tulip via-rhine ne2k-pci 8139too),
diff --git a/kernel/update_kernel b/kernel/update_kernel
index cfa157350..427bb249f 100755
--- a/kernel/update_kernel
+++ b/kernel/update_kernel
@@ -1,7 +1,7 @@
#!/bin/bash
ALL_KERNELS="all.kernels"
-RPMS=/export/Mandrake/RPMS
+RPMS=/export/media/main
ARCH=`uname -m | sed -e 's/i.86/i386/' -e 's/sparc.*/sparc/'`
diff --git a/mdk-stage1/config-stage1.h b/mdk-stage1/config-stage1.h
index 1b9dae230..2a9cfa9ce 100644
--- a/mdk-stage1/config-stage1.h
+++ b/mdk-stage1/config-stage1.h
@@ -27,8 +27,8 @@
#define RAMDISK_COMPRESSION_RATIO 1.95
-#define LIVE_LOCATION "/Mandrake/mdkinst/"
-#define RAMDISK_LOCATION "/Mandrake/base/"
+#define LIVE_LOCATION "/install/stage2/live/"
+#define RAMDISK_LOCATION "/install/stage2/"
#define SLASH_LOCATION "/sysroot"
#define STAGE2_LOCATION SLASH_LOCATION "/tmp/stage2"
diff --git a/mdk-stage1/disk.c b/mdk-stage1/disk.c
index 9ae6b74d8..716b38f7e 100644
--- a/mdk-stage1/disk.c
+++ b/mdk-stage1/disk.c
@@ -360,9 +360,9 @@ process_recovery(void)
goto examine_next_part;
}
strcpy(location, disk_own_mount);
- strcat(location, "/Mandrake/base");
+ strcat(location, "/install/stage2");
if (access(location, R_OK)) {
- log_message("Mandrake/base is not here");
+ log_message("install/stage2 is not here");
goto examine_next_part;
}
diff --git a/mdk-stage1/doc/TECH-INFOS b/mdk-stage1/doc/TECH-INFOS
index c85288617..e66c9daa5 100644
--- a/mdk-stage1/doc/TECH-INFOS
+++ b/mdk-stage1/doc/TECH-INFOS
@@ -91,7 +91,7 @@ This gives for example for:
You may specify a stage2 auto-install file, different from the
-default `auto_inst.cfg.pl' in Mandrake/base, by filling the
+default `auto_inst.cfg.pl' in install/, by filling the
`bootfile' parameter of your DHCP server response.
Note that if the name ends with `-IP' or `-IP.pl', IP will be
diff --git a/mdk-stage1/network.c b/mdk-stage1/network.c
index 2f245d97f..b8c77dccf 100644
--- a/mdk-stage1/network.c
+++ b/mdk-stage1/network.c
@@ -669,7 +669,7 @@ static int mirrorlist_entry_split(const char *entry, char *mirror[4]) /* mirror
mirror[2] = strndup(entry, host_sep - entry);
entry = host_sep;
- path_sep = strstr(entry, "/Mandrake/RPMS");
+ path_sep = strstr(entry, "/media/main");
if (!path_sep || path_sep == entry) {
log_message("NETWORK: this path isn't valid : \"%s\"", entry);
return -1;
diff --git a/perl-install/Makefile b/perl-install/Makefile
index eca24f33e..64e9ef435 100644
--- a/perl-install/Makefile
+++ b/perl-install/Makefile
@@ -3,6 +3,7 @@ PKGVERSION:=$(shell rpm -q --qf '%{VERSION}\n' --specfile $(PACKAGE).spec|head -
RELEASE:=$(shell rpm -q --qf '%{RELEASE}\n' --specfile $(PACKAGE).spec|head -n 1)
TAG := $(shell echo "V$(PKGVERSION)_$(RELEASE)" | tr -- '-.' '__')
+include ../Makefile.config
include Makefile.config
POFILES = $(shell ls share/po/*.po)
@@ -108,7 +109,7 @@ get_needed_files: $(DIRS) mo_files
install -d $(DEST)/usr/share/gtk
install -d $(DEST)/usr/share/xmodmap
install -d $(DEST)/usr/X11R6/lib/X11
- install -d $(ROOTDEST)/Mandrake/base
+ install -d $(MEDIA_INFO_DEST)
install -s $(LOCALFILES) $(DEST)/usr/bin
# cp -f $(LOCALFILES2) $(DEST)/usr/bin
ln -s ../X11R6/lib/X11 $(DEST)/usr/lib/X11
@@ -171,9 +172,9 @@ endif
-cd share ; cp -f *.png $(DEST)/usr/share
-cd pixmaps ; cp -af *.png *.xpm $(DEST)/usr/share ; rm -f $(DEST)/usr/share/wiz_*
cp `perl -I. -Mlang -e 'lang::png_lang_files()'` $(DEST)/usr/share/langs
- cd share ; cp compssUsers compssUsers.* rpmsrate $(ROOTDEST)/Mandrake/base
+ cd share ; cp compssUsers compssUsers.* rpmsrate $(MEDIA_INFO_DEST)
- clean-rpmsrate $(ROOTDEST)/Mandrake/base/rpmsrate $(ROOTDEST)/Mandrake/RPMS*
+ clean-rpmsrate $(MEDIA_INFO_DEST)/rpmsrate $(MAIN_RPMS_DIR)
for i in ../kernel/modules.description ../kernel/all.modules/modules.cz*; do cp -f $$i $(DEST)/lib/; done
@@ -194,7 +195,7 @@ endif
full_stage2:
$(MAKE) stage2
- $(ROOTDEST)/misc/make_mdkinst_stage2 $(DEST) $(ROOTDEST)/Mandrake/base/mdkinst_stage2
+ $(MISC_DEST)/make_mdkinst_stage2 $(DEST) $(STAGE2_DEST)/mdkinst_stage2
stage2:
if [ `id -u` = 0 ]; then rm -rf $(DEST); else $(SUDO) rm -rf $(DEST); fi
diff --git a/perl-install/Makefile.config b/perl-install/Makefile.config
index 6030fd98b..89f63c069 100644
--- a/perl-install/Makefile.config
+++ b/perl-install/Makefile.config
@@ -1,17 +1,8 @@
# -*- Makefile -*-
-ARCH := $(patsubst i%86,i386,$(shell uname -m))
-ARCH := $(patsubst sparc%,sparc,$(ARCH))
-
-ifeq (x86_64, $(ARCH))
-LIB = lib64
-else
-LIB = lib
-endif
-
VERSION = 2.2.10-BOOT
SUDO = sudo
SO_FILES = c/blib/arch/auto/c/c.so
-PMS_DIRS = Newt Xconfig c xf86misc diskdrake harddrake interactive modules network partition_table printer resize_fat sbus_probing security
+PMS_DIRS = Newt Xconfig c xf86misc diskdrake harddrake interactive modules network partition_table printer resize_fat sbus_probing security fs
PMS = *.pm $(PMS_DIRS:%=%/*.pm) commands install2
STANDALONEPMS_ = XFdrake adduserdrake diskdrake drakTermServ drakautoinst drakauth drakbackup drakboot drakbug drakbug_report drakclock drakconnect drakedm drakfirewall drakfloppy drakfont drakgw drakhelp drakperm drakproxy drakpxe draksec draksound draksplash drakupdate_fstab drakups drakvpn drakxservices drakxtv fileshareset harddrake2 keyboarddrake localedrake logdrake lsnetdrake mousedrake net_applet net_monitor printerdrake scannerdrake service_harddrake service_harddrake_confirm bootloader-config
@@ -19,9 +10,7 @@ STANDALONEPMS = $(STANDALONEPMS_:%=standalone/%)
ALLPMS = $(PMS) $(STANDALONEPMS) share/advertising/*.pl
REP4PMS = /usr/bin/perl-install
ROOTDEST = /export
-DEST = $(ROOTDEST)/Mandrake/mdkinst
-STAGE2 = $(ROOTDEST)/Mandrake/base/mdkinst_stage2
-BASE = $(ROOTDEST)/Mandrake/base
+DEST = $(STAGE2_LIVE)
DESTREP4PMS = $(DEST)$(REP4PMS)
PERL = perl
LOCALFILES = $(patsubst %, ../tools/%,ddcprobe/ddcxinfos serial_probe/serial_probe xhost+)
diff --git a/perl-install/Makefile.drakxtools b/perl-install/Makefile.drakxtools
index 8746ba7ea..f0cbadadf 100644
--- a/perl-install/Makefile.drakxtools
+++ b/perl-install/Makefile.drakxtools
@@ -1,4 +1,5 @@
# -*- Makefile -*-
+include ../Makefile.config
include Makefile.config
INLIBDEST_DIRS = Newt c resize_fat xf86misc sbus_probing
diff --git a/perl-install/install2.pm b/perl-install/install2.pm
index bc25dcf5f..8d785cae7 100644
--- a/perl-install/install2.pm
+++ b/perl-install/install2.pm
@@ -420,7 +420,7 @@ sub main {
} %cmdline;
if ($::testing) {
- $ENV{SHARE_PATH} ||= "/export/Mandrake/mdkinst/usr/share";
+ $ENV{SHARE_PATH} ||= "/export/install/stage2/live/usr/share";
$ENV{SHARE_PATH} = "/usr/share" if !-e $ENV{SHARE_PATH};
} else {
$ENV{SHARE_PATH} ||= "/usr/share";
@@ -531,9 +531,9 @@ sub main {
modules::load_category($o->{modules_conf}, 'bus/usb');
#- oem patch should be read before to still allow patch or defcfg.
- eval { $o = $::o = install_any::loadO($o, "Mandrake/base/patch-oem.pl"); log::l("successfully read oem patch") };
+ eval { $o = $::o = install_any::loadO($o, "install/patch-oem.pl"); log::l("successfully read oem patch") };
#- recovery mode should be read early to allow default parameter to be taken.
- eval { $o = $::o = install_any::loadO($o, "Mandrake/base/recovery.cfg"); log::l("successfully read recovery") } if $::recovery;
+ eval { $o = $::o = install_any::loadO($o, "install/recovery.cfg"); log::l("successfully read recovery") } if $::recovery;
$@ and $::recovery = 0; #- avoid keeping recovery if there was a problem reading the recovery.cfg file.
#- patch should be read after defcfg in order to take precedance.
eval { $o = $::o = install_any::loadO($o, $cfg); log::l("successfully read default configuration: $cfg") } if $cfg;
@@ -669,7 +669,7 @@ sub main {
#- save recovery file if needed (ie disk style install).
$o->{method} eq 'disk' and
- output($o->{prefix}.any::hdInstallPath()."/Mandrake/base/recovery.cfg", install_any::g_auto_install(1));
+ output($o->{prefix} . any::hdInstallPath() . '/install/recovery.cfg', install_any::g_auto_install(1));
#- mainly for auto_install's
#- do not use run_program::xxx because it doesn't leave stdin/stdout unchanged
diff --git a/perl-install/install_steps.pm b/perl-install/install_steps.pm
index 625e1d941..645f3fe0d 100644
--- a/perl-install/install_steps.pm
+++ b/perl-install/install_steps.pm
@@ -338,7 +338,7 @@ sub beforeInstallPackages {
#- add oem theme if the files exists.
mkdir_p("$o->{prefix}/usr/share");
- install_any::getAndSaveFile("Mandrake/base/oem-theme.rpm", "$o->{prefix}/usr/share/oem-theme.rpm");
+ install_any::getAndSaveFile("install/oem-theme.rpm", "$o->{prefix}/usr/share/oem-theme.rpm");
}
sub pkg_install {
@@ -406,7 +406,7 @@ sub afterInstallPackages($) {
die N("Some important packages didn't get installed properly.
Either your cdrom drive or your cdrom is defective.
-Check the cdrom on an installed computer using \"rpm -qpl Mandrake/RPMS/*.rpm\"
+Check the cdrom on an installed computer using \"rpm -qpl media/main/*.rpm\"
") if any { m|read failed: Input/output error| } cat_("$o->{prefix}/root/drakx/install.log");
if (arch() !~ /^sparc/) { #- TODO restore it as may be needed for sparc
diff --git a/perl-install/install_steps_gtk.pm b/perl-install/install_steps_gtk.pm
index 606252218..cf7ad0cdf 100644
--- a/perl-install/install_steps_gtk.pm
+++ b/perl-install/install_steps_gtk.pm
@@ -114,7 +114,7 @@ sub new($$) {
my ($prog, $Driver) = /Driver:(.*)/ ? ('Xorg', $1) : /Xsun|Xpmac|Xnest|^X_move$/ ? $_ : "XF86_$_";
unless (-x "$dir/$prog") {
unlink $_ foreach glob_("$dir/X*");
- install_any::getAndSaveFile("Mandrake/mdkinst$dir/$prog", "$dir/$prog") or die "failed to get server $prog: $!";
+ install_any::getAndSaveFile("install/stage2/live$dir/$prog", "$dir/$prog") or die "failed to get server $prog: $!";
chmod 0755, "$dir/$prog";
}
if (/FB/i) {
diff --git a/perl-install/lang.pm b/perl-install/lang.pm
index 59ee3e5bb..499c15bac 100644
--- a/perl-install/lang.pm
+++ b/perl-install/lang.pm
@@ -873,7 +873,7 @@ sub set {
symlink "../$main_charset/$_", "$dir/$lang/$_" foreach @LCs, 'LC_MESSAGES';
#- getting LC_CTYPE (putting it directly in $lang)
- install_any::getAndSaveFile("Mandrake/mdkinst$dir/$charset/LC_CTYPE", "$dir/$lang/LC_CTYPE");
+ install_any::getAndSaveFile("install/stage2/live$dir/$charset/LC_CTYPE", "$dir/$lang/LC_CTYPE");
}
#- set all LC_* variables to a unique locale ("C"), and only redefine
diff --git a/perl-install/modules.pm b/perl-install/modules.pm
index 6370ba600..8ea7ba431 100644
--- a/perl-install/modules.pm
+++ b/perl-install/modules.pm
@@ -258,7 +258,7 @@ sub extract_modules {
if (!-e $cz) {
unlink $_ foreach glob_("/lib/modules*.cz*");
require install_any;
- install_any::getAndSaveFile("Mandrake/mdkinst$cz", $cz) or die "failed to get modules $cz: $!";
+ install_any::getAndSaveFile("install/stage2/live$cz", $cz) or die "failed to get modules $cz: $!";
}
eval {
require packdrake;
diff --git a/perl-install/pkgs.pm b/perl-install/pkgs.pm
index 62eccef1a..5a31480e1 100644
--- a/perl-install/pkgs.pm
+++ b/perl-install/pkgs.pm
@@ -361,25 +361,25 @@ sub psUpdateHdlistsDeps {
my $hdlistf = "$urpmidir/hdlist.$_->{fakemedium}.cz" . ($_->{hdlist} =~ /\.cz2/ && "2");
my $synthesisf = "$urpmidir/synthesis.hdlist.$_->{fakemedium}.cz" . ($_->{hdlist} =~ /\.cz2/ && "2");
if (-s $hdlistf != $_->{hdlist_size}) {
- install_any::getAndSaveFile("Mandrake/base/$_->{hdlist}", $hdlistf) or die "no $_->{hdlist} found";
+ install_any::getAndSaveFile("media/media_info/$_->{hdlist}", $hdlistf) or die "no $_->{hdlist} found";
symlinkf $hdlistf, "/tmp/$_->{hdlist}";
++$need_copy;
}
if (-s $synthesisf != $_->{synthesis_hdlist_size}) {
- install_any::getAndSaveFile("Mandrake/base/synthesis.$_->{hdlist}", $synthesisf);
+ install_any::getAndSaveFile("media/media_info/synthesis.$_->{hdlist}", $synthesisf);
-s $synthesisf > 0 or unlink $synthesisf;
}
}
if ($need_copy) {
#- this is necessary for urpmi.
- install_any::getAndSaveFile("Mandrake/base/$_", "$urpmidir/$_") foreach qw(rpmsrate);
+ install_any::getAndSaveFile("media/media_info/$_", "$urpmidir/$_") foreach qw(rpmsrate);
}
}
sub psUsingHdlists {
my ($prefix, $method) = @_;
- my $listf = install_any::getFile('Mandrake/base/hdlists') or die "no hdlists found";
+ my $listf = install_any::getFile('media/media_info/hdlists') or die "no hdlists found";
my $packages = new URPM;
my $suppl_CDs = 0;
@@ -434,7 +434,7 @@ sub psUsingHdlist {
#- for getting header of package during installation or after by urpmi.
my $newf = "$urpmidir/hdlist.$fakemedium.cz" . ($hdlist =~ /\.cz2/ && "2");
-e $newf and do { unlink $newf or die "cannot remove $newf: $!" };
- install_any::getAndSaveFile($o_fhdlist || "Mandrake/base/$hdlist", $newf) or do { unlink $newf; die "no $hdlist found" };
+ install_any::getAndSaveFile($o_fhdlist || "media/media_info/$hdlist", $newf) or do { unlink $newf; die "no $hdlist found" };
$m->{hdlist_size} = -s $newf; #- keep track of size for post-check.
symlinkf $newf, "/tmp/$hdlist";
@@ -442,7 +442,7 @@ sub psUsingHdlist {
my $newsf = "$urpmidir/synthesis.hdlist.$fakemedium.cz" . ($hdlist =~ /\.cz2/ && "2");
unless ($o_fhdlist) {
#- copy existing synthesis file too.
- install_any::getAndSaveFile("Mandrake/base/synthesis.$hdlist", $newsf);
+ install_any::getAndSaveFile("media/media_info/synthesis.$hdlist", $newsf);
$m->{synthesis_hdlist_size} = -s $newsf; #- keep track of size for post-check.
-s $newsf > 0 or unlink $newsf;
}
@@ -452,7 +452,7 @@ sub psUsingHdlist {
if (!$o_fhdlist || $o_pubkey) {
$m->{pubkey} = $o_pubkey;
unless ($m->{pubkey}) {
- my $pubkey = install_any::getFile("Mandrake/base/pubkey" . ($hdlist =~ /hdlist(\S*)\.cz2?/ && $1));
+ my $pubkey = install_any::getFile("media/media_info/pubkey" . ($hdlist =~ /hdlist(\S*)\.cz2?/ && $1));
$m->{pubkey} = [ $packages->parse_armored_file($pubkey) ];
}
}
@@ -579,7 +579,7 @@ sub read_rpmsrate {
sub readCompssUsers {
my ($meta_class, $file) = @_;
- $file ||= 'Mandrake/base/compssUsers';
+ $file ||= 'media/media_info/compssUsers';
my $f = $meta_class && install_any::getFile("$file.$meta_class") || install_any::getFile($file) or die "can't find $file";
readCompssUsers_raw($f);
}
diff --git a/perl-install/share/advertising/Makefile b/perl-install/share/advertising/Makefile
index 0ac5a0a86..c9313c3aa 100644
--- a/perl-install/share/advertising/Makefile
+++ b/perl-install/share/advertising/Makefile
@@ -1,10 +1,11 @@
-include ../../Makefile.config
+include ../../../Makefile.config
PRODUCT = dwd
+DESTDIR = $(EXTRA_INSTALL_DEST)/advertising
install:
- rm -rf $(ROOTDEST)/Mandrake/share/advertising
- install -d $(ROOTDEST)/Mandrake/share/advertising
- install -m755 `cat list-$(PRODUCT) | sed 's/png$$/pl/'` $(ROOTDEST)/Mandrake/share/advertising
- install -m644 `cat list-$(PRODUCT)` $(ROOTDEST)/Mandrake/share/advertising
- install -m644 list-$(PRODUCT) $(ROOTDEST)/Mandrake/share/advertising/list
+ rm -rf $(DESTDIR)
+ install -d $(DESTDIR)
+ install -m755 `cat list-$(PRODUCT) | sed 's/png$$/pl/'` $(DESTDIR)
+ install -m644 `cat list-$(PRODUCT)` $(DESTDIR)
+ install -m644 list-$(PRODUCT) $(DESTDIR)/list
diff --git a/perl-install/share/po/Makefile b/perl-install/share/po/Makefile
index 2dca05819..92b6613af 100644
--- a/perl-install/share/po/Makefile
+++ b/perl-install/share/po/Makefile
@@ -1,3 +1,4 @@
+include ../../../Makefile.config
include ../../Makefile.config
PMSFILES = $(ALLPMS) ../move/move.pm ../move/tree/mdk_totem
diff --git a/perl-install/standalone/drakpxe b/perl-install/standalone/drakpxe
index 94640b458..1d2ca35ce 100755
--- a/perl-install/standalone/drakpxe
+++ b/perl-install/standalone/drakpxe
@@ -192,7 +192,7 @@ If you do not have an existing directory, please copy the CD or DVD contents.
[ { label => N("Installation image directory"), val => \$dir, type => 'entry' }, ])
or goto step_ip_range;
-unless (-d $dir && -e "$dir/VERSION" && -d "$dir/isolinux" && -d "$dir/Mandrake/base") {
+unless (-d $dir && -e "$dir/VERSION" && -d "$dir/install/isolinux" && -d "$dir/install/stage2") {
$in->ask_warn(N("No image found"),
N("No CD or DVD image found, please copy the installation program and rpm files."));
goto step_install_dir;
@@ -203,7 +203,7 @@ unless (-d $dir && -e "$dir/VERSION" && -d "$dir/isolinux" && -d "$dir/Mandrake/
step_auto_install:
-my $auto_inst_cfg = "Mandrake/base/auto_inst.cfg"; #- TODO change according configuration?
+my $auto_inst_cfg = "install/auto_inst.cfg"; #- TODO change according configuration?
-e "$dir/$auto_inst_cfg" or $auto_inst_cfg = '';
$in->ask_from('Choose auto installation',
@@ -246,7 +246,7 @@ build_dhcpd_conf($dhcpd_conf, "/etc/dhcpd.conf");
#- make kernel and initrd available for initrd.
mkdir "/var/lib/tftpboot/PXEClient/images";
-sys("cp", "-af", "$dir/isolinux/alt0", "/var/lib/tftpboot/PXEClient/images/");
+sys("cp", "-af", "$dir/install/isolinux/alt0", "/var/lib/tftpboot/PXEClient/images/");
my $pxelinux_cfg = parse_pxelinux_cfg("/var/lib/tftpboot/PXEClient/pxelinux.cfg/default");
my $label;
diff --git a/rescue/Makefile b/rescue/Makefile
index bbc0d7dda..b43275b94 100644
--- a/rescue/Makefile
+++ b/rescue/Makefile
@@ -1,13 +1,9 @@
-ARCH := $(patsubst i%86,i386,$(shell uname -m))
-ARCH := $(patsubst sparc%,sparc,$(ARCH))
-
-
-ROOTDEST = /export
+include ../Makefile.config
all: rescue_stage2.bz2
install: rescue_stage2.bz2
- cp -f $< $(ROOTDEST)/Mandrake/base
+ cp -f $< $(STAGE2_DEST)
rescue_stage2.bz2: kernel_read_part list list.$(ARCH) drvinst guessmounts lsparts rescue-doc make_rescue_img
./make_rescue_img
diff --git a/tools/Makefile b/tools/Makefile
index cafff8e29..d9c2b283a 100644
--- a/tools/Makefile
+++ b/tools/Makefile
@@ -1,8 +1,7 @@
-ROOTDEST = /export
-DEST = $(ROOTDEST)/Mandrake/mdkinst
-RPMS = $(wildcard $(ROOTDEST)/Mandrake/RPMS/*.rpm)
+include ../Makefile.config
+
+RPMS = $(wildcard $(MAIN_RPMS_DIR)/*.rpm)
DIRS = ddcprobe serial_probe
-BASE = $(ROOTDEST)/Mandrake/base
CFLAGS = -Wall
ARCH := $(shell arch | egrep "(x86_64|sparc64|s390x)")
@@ -20,14 +19,14 @@ $(DIRS):
make -C $@
install:
- @install -d $(ROOTDEST)/misc/auto
- @install make_mdkinst_stage2 $(ROOTDEST)/misc
- @cp -rf `perl -Mpackdrake -le 'print $$INC{"packdrake.pm"}'` $(ROOTDEST)/misc || { echo "install rpmtools first!" ; exit 1; }
- @cp -rf `perl -MURPM -le 'print $$INC{"URPM.pm"}' | sed s/URPM.pm//`URPM* $(ROOTDEST)/misc || { echo "install perl-URPM first!" ; exit 1; }
- @cp -rf `perl -MURPM -le 'print $$INC{"URPM.pm"}' | sed s/URPM.pm//`auto/URPM $(ROOTDEST)/misc/auto || { echo "install perl-URPM first!" ; exit 1; }
- @cd /usr/bin ; install packdrake $(ROOTDEST)/misc || { echo "packdrake is missing"; exit 1; }
- @cd /usr/bin ; install gendistrib rpm2header $(ROOTDEST)/misc || { echo "install rpmtools first!" ; exit 1; }
- @mkdir -p $(DEST)/usr/bin
+ @install -d $(MISC_DEST)/auto
+ @install make_mdkinst_stage2 $(MISC_DEST)
+ cp -rf `perl -Mpackdrake -le 'print $$INC{"packdrake.pm"}'` $(MISC_DEST) || { echo "install rpmtools first!" ; exit 1; }
+ @cp -rf `perl -MURPM -le 'print $$INC{"URPM.pm"}' | sed s/URPM.pm//`URPM* $(MISC_DEST) || { echo "install perl-URPM first!" ; exit 1; }
+ @cp -rf `perl -MURPM -le 'print $$INC{"URPM.pm"}' | sed s/URPM.pm//`auto/URPM $(MISC_DEST)/auto || { echo "install perl-URPM first!" ; exit 1; }
+ @cd /usr/bin ; install packdrake $(MISC_DEST) || { echo "packdrake is missing"; exit 1; }
+ @cd /usr/bin ; install gendistrib rpm2header $(MISC_DEST) || { echo "install rpmtools first!" ; exit 1; }
+ @mkdir -p $(STAGE2_LIVE)/usr/bin
xhost+: %: %.c
$(CC) $(CFLAGS) $< -L/usr/X11R6/$(LIB_NAME) -lX11 -o $@
diff --git a/tools/i386/netboot/menu.lst.example b/tools/i386/netboot/menu.lst.example
index 41022579a..3465fac62 100644
--- a/tools/i386/netboot/menu.lst.example
+++ b/tools/i386/netboot/menu.lst.example
@@ -4,18 +4,18 @@ default 0
title nfs
dhcp
tftpserver 192.168.100.39
-kernel (nd)/vmlinuz ramdisk=32000 vga=788 kickstart=Mandrake/base/auto_inst.cfg.pl useless_thing_accepted automatic=method:nfs,network:static,ip:192.168.100.25,dns:192.168.100.11,gateway:192.168.100.1,server:192.168.100.39,directory:/export,user:a,pass:a
+kernel (nd)/vmlinuz ramdisk=32000 vga=788 kickstart=install/auto_inst.cfg.pl useless_thing_accepted automatic=method:nfs,network:static,ip:192.168.100.25,dns:192.168.100.11,gateway:192.168.100.1,server:192.168.100.39,directory:/export,user:a,pass:a
initrd (nd)/network.rdz
title ftp
dhcp
tftpserver 192.168.100.39
-kernel (nd)/vmlinuz ramdisk=32000 vga=788 kickstart=Mandrake/base/auto_inst.cfg.pl useless_thing_accepted automatic=method:ftp,network:static,ip:192.168.100.25,dns:192.168.100.11,gateway:192.168.100.1,server:192.168.100.39,directory:/export,user:a,pass:a
+kernel (nd)/vmlinuz ramdisk=32000 vga=788 kickstart=install/auto_inst.cfg.pl useless_thing_accepted automatic=method:ftp,network:static,ip:192.168.100.25,dns:192.168.100.11,gateway:192.168.100.1,server:192.168.100.39,directory:/export,user:a,pass:a
initrd (nd)/network.rdz
title rescue
dhcp
tftpserver 192.168.100.39
-kernel (nd)/vmlinuz rescue rw root=/dev/ram3 ramdisk=32000 vga=788 kickstart=Mandrake/base/auto_inst.cfg.pl useless_thing_accepted automatic=method:nfs,network:static,ip:192.168.100.25,dns:192.168.100.11,gateway:192.168.100.1,server:192.168.100.39,directory:/export,user:a,pass:a
+kernel (nd)/vmlinuz rescue rw root=/dev/ram3 ramdisk=32000 vga=788 kickstart=install/auto_inst.cfg.pl useless_thing_accepted automatic=method:nfs,network:static,ip:192.168.100.25,dns:192.168.100.11,gateway:192.168.100.1,server:192.168.100.39,directory:/export,user:a,pass:a
initrd (nd)/network.rdz
diff --git a/tools/make_mdkinst_stage2 b/tools/make_mdkinst_stage2
index 7af43d726..babb3d567 100755
--- a/tools/make_mdkinst_stage2
+++ b/tools/make_mdkinst_stage2
@@ -2,7 +2,7 @@
[ $# != 2 ] && {
echo "usage: make_mdkinst_stage2 <live dir> <output image>" ;
- echo " example: misc/make_mdkinst_stage2 Mandrake/mdkinst Mandrake/base/mdkinst_stage2"
+ echo " example: misc/make_mdkinst_stage2 install/stage2/live install/stage2/mdkinst_stage2"
exit
}
@@ -17,8 +17,8 @@ STAGE2=$2
testandset() { [ -x $1/packdrake ] && BUILD_ARCHIVE=$1/packdrake; }
testandset `pwd`/misc
testandset `pwd`/.
-testandset /$DEST/../../misc
-testandset `pwd`/$DEST/../../misc
+testandset /$DEST/../../../misc
+testandset `pwd`/$DEST/../../../misc
[ -z "$BUILD_ARCHIVE" ] && { echo "can't find packdrake"; exit 1; }
if [ $EUID != "0" ]; then
diff --git a/perl-install/install_any.pm b/perl-install/install_any.pm
index 286e88be8..66511f2e1 100644
--- a/perl-install/install_any.pm
+++ b/perl-install/install_any.pm
@@ -212,7 +212,7 @@ sub getFile {
} || errorOpeningFile($f);
}
sub getAndSaveFile {
- my ($file, $local) = @_ == 1 ? ("Mandrake/mdkinst$_[0]", $_[0]) : @_;
+ my ($file, $local) = @_ == 1 ? ("install/stage2/live$_[0]", $_[0]) : @_;
local $/ = \ (16 * 1024);
my $f = ref($file) ? $file : getFile($file) or return;
open(my $F, ">$local") or log::l("getAndSaveFile(opening $local): $!"), return;
@@ -390,10 +390,10 @@ sub setPackages {
$o->{packages},
"hdlist$medium.cz",
$medium,
- 'Mandrake/RPMS',
+ 'media/main',
"Supplementary CD $medium",
1, # selected
- "/mnt/cdrom/Mandrake/base/hdlist$medium.cz",
+ "/mnt/cdrom/media/main/media_info/hdlist$medium.cz",
);
if ($supplmedium) {
log::l("read suppl hdlist");
@@ -426,11 +426,11 @@ sub setPackages {
#- if there is a supplementary CD, override the rpmsrate/compssUsers
pkgs::read_rpmsrate(
$o->{packages},
- getFile($suppl_CDs ? "/mnt/cdrom/Mandrake/base/rpmsrate" : "Mandrake/base/rpmsrate")
+ getFile($suppl_CDs ? "/mnt/cdrom/media/media_info/rpmsrate" : "media/media_info/rpmsrate")
);
($o->{compssUsers}, $o->{compssUsersSorted}) = pkgs::readCompssUsers(
$o->{meta_class},
- $suppl_CDs ? "/mnt/cdrom/Mandrake/base/compssUsers" : "",
+ $suppl_CDs ? "/mnt/cdrom/media/media_info/compssUsers" : "",
);
#- preselect default_packages and compssUsersChoices.
@@ -674,7 +674,7 @@ sub install_urpmi {
http => $ENV{URLPREFIX},
cdrom => "removable://mnt/cdrom" }}{$method} ||
#- for live_update or live_install script.
- readlink("/tmp/image/Mandrake") =~ m,^(/.*)/Mandrake/*$, && "removable:/$1") . "/$_->{rpmsdir}";
+ readlink("/tmp/image/media") =~ m,^(/.*)/media/*$, && "removable:/$1") . "/$_->{rpmsdir}";
#- use list file only if visible password or macro.
my $need_list = $dir =~ m,^(?:[^:]*://[^/:\@]*:[^/:\@]+\@|.*%{),; #- }
@@ -720,7 +720,7 @@ sub install_urpmi {
my ($qname, $qdir) = ($name, $dir);
$qname =~ s/(\s)/\\$1/g; $qdir =~ s/(\s)/\\$1/g;
#- compute correctly reference to Mandrake/base
my $with;
if ($_->{update}) {
#- an update medium always use "../base/hdlist.cz";
@@ -729,7 +729,7 @@ sub install_urpmi {
$with = $_->{rpmsdir};
$with =~ s|/[^/]*%{ARCH}.*||;
$with =~ s|/+|/|g; $with =~ s|/$||; $with =~ s|[^/]||g; $with =~ s!/!../!g;
- $with .= "../Mandrake/base/$_->{hdlist}";
+ $with .= "../media/media_info/$_->{hdlist}";
}
#- output new urpmi.cfg format here.
@@ -862,9 +862,9 @@ sub getAndSaveInstallFloppies {
$image .= arch() =~ /sparc64/ && "64"; #- for sparc64 there are a specific set of image.
if ($have_drivers) {
- getAndSaveFile("images/${image}_drivers.img", "$dest_dir/${name}_drivers.img") or log::l("failed to write Install Floppy (${image}_drivers.img) to $dest_dir/${name}_drivers.img"), return;
+ getAndSaveFile("install/images/${image}_drivers.img", "$dest_dir/${name}_drivers.img") or log::l("failed to write Install Floppy (${image}_drivers.img) to $dest_dir/${name}_drivers.img"), return;
}
- getAndSaveFile("images/$image.img", "$dest_dir/$name.img") or log::l("failed to write Install Floppy ($image.img) to $dest_dir/$name.img"), return;
+ getAndSaveFile("install/images/$image.img", "$dest_dir/$name.img") or log::l("failed to write Install Floppy ($image.img) to $dest_dir/$name.img"), return;
"$dest_dir/$name.img", if_($have_drivers, "$dest_dir/${name}_drivers.img");
}
@@ -1162,7 +1162,7 @@ sub copy_advertising {
return if $::rootwidth < 800;
my $f;
- my $source_dir = "Mandrake/share/advertising";
+ my $source_dir = "install/extra/advertising";
foreach ("." . $o->{locale}{lang}, "." . substr($o->{locale}{lang},0,2), '') {
$f = getFile("$source_dir$_/list") or next;
$source_dir = "$source_dir$_";
@@ -720,7 +720,7 @@ sub install_urpmi {
my ($qname, $qdir) = ($name, $dir);
$qname =~ s/(\s)/\\$1/g; $qdir =~ s/(\s)/\\$1/g;
- #- compute correctly reference to Mandrake/base
+ #- compute correctly reference to media/media_info
my $with;
if ($_->{update}) {